==> camel-k-model-v1-5.3.0-sources.jar: io/fabric8/camelk/v1/IntegrationKitListFluent.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface IntegrationKitListFluent<A extends IntegrationKitListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public A addToItems(int index,IntegrationKit item);
    public A setToItems(int index,IntegrationKit item);
    public A addToItems(IntegrationKit... items);
    public A addAllToItems(Collection<IntegrationKit> items);
    public A removeFromItems(IntegrationKit... items);
    public A removeAllFromItems(Collection<IntegrationKit> items);
    public A removeMatchingFromItems(Predicate<IntegrationKitBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<IntegrationKit> getItems();
    public List<IntegrationKit> buildItems();
    public IntegrationKit buildItem(int index);
    public IntegrationKit buildFirstItem();
    public IntegrationKit buildLastItem();
    public IntegrationKit buildMatchingItem(Predicate<IntegrationKitBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<IntegrationKitBuilder> predicate);
    public A withItems(List<IntegrationKit> items);
    public A withItems(IntegrationKit... items);
    public Boolean hasItems();
    public IntegrationKitListFluent.ItemsNested<A> addNewItem();
    public IntegrationKitListFluent.ItemsNested<A> addNewItemLike(IntegrationKit item);
    public IntegrationKitListFluent.ItemsNested<A> setNewItemLike(int index,IntegrationKit item);
    public IntegrationKitListFluent.ItemsNested<A> editItem(int index);
    public IntegrationKitListFluent.ItemsNested<A> editFirstItem();
    public IntegrationKitListFluent.ItemsNested<A> editLastItem();
    public IntegrationKitListFluent.ItemsNested<A> editMatchingItem(Predicate<IntegrationKitBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IntegrationKitFluent<IntegrationKitListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}

==> camel-k-model-v1-5.3.1-sources.jar: io/fabric8/camelk/v1/IntegrationKitListFluent.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface IntegrationKitListFluent<A extends IntegrationKitListFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public A addToItems(int index,IntegrationKit item);
    public A setToItems(int index,IntegrationKit item);
    public A addToItems(IntegrationKit... items);
    public A addAllToItems(Collection<IntegrationKit> items);
    public A removeFromItems(IntegrationKit... items);
    public A removeAllFromItems(Collection<IntegrationKit> items);
    public A removeMatchingFromItems(Predicate<IntegrationKitBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<IntegrationKit> getItems();
    public List<IntegrationKit> buildItems();
    public IntegrationKit buildItem(int index);
    public IntegrationKit buildFirstItem();
    public IntegrationKit buildLastItem();
    public IntegrationKit buildMatchingItem(Predicate<IntegrationKitBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<IntegrationKitBuilder> predicate);
    public A withItems(List<IntegrationKit> items);
    public A withItems(IntegrationKit... items);
    public Boolean hasItems();
    public io.fabric8.camelk.v1.IntegrationKitListFluent.ItemsNested<A> addNewItem();
    public io.fabric8.camelk.v1.IntegrationKitListFluent.ItemsNested<A> addNewItemLike(IntegrationKit item);
    public io.fabric8.camelk.v1.IntegrationKitListFluent.ItemsNested<A> setNewItemLike(int index,IntegrationKit item);
    public io.fabric8.camelk.v1.IntegrationKitListFluent.ItemsNested<A> editItem(int index);
    public io.fabric8.camelk.v1.IntegrationKitListFluent.ItemsNested<A> editFirstItem();
    public io.fabric8.camelk.v1.IntegrationKitListFluent.ItemsNested<A> editLastItem();
    public io.fabric8.camelk.v1.IntegrationKitListFluent.ItemsNested<A> editMatchingItem(Predicate<IntegrationKitBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,IntegrationKitFluent<io.fabric8.camelk.v1.IntegrationKitListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}
